/**
 * 
 */
package net.bigeon.gclc.process;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.io.IOException;

import org.junit.Test;

import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.exception.CommandRunExceptionType;
import net.bigeon.gclc.manager.PipedConsoleOutput;
import net.bigeon.gclc.process.mocks.TaskMock;

/** @author Emmanuel Bigeon */
public class ProcessListTest {

    /** Test method for
     * {@link net.bigeon.gclc.process.ProcessList#ProcessList(java.lang.String, net.bigeon.gclc.process.TaskPool)}. */
    @Test
    public void testProcessList() {
        final ProcessList pl = new ProcessList("list", new TaskPool());
        assertEquals("Command name should be kept as specified", "list",
                pl.getCommandName());
    }

    /** Test method for
     * {@link net.bigeon.gclc.process.ProcessList#execute(net.bigeon.gclc.manager.ConsoleOutput, net.bigeon.gclc.manager.ConsoleInput, java.lang.String[])}.
     * 
     * @throws CommandRunException if an error occured
     * @throws IOException if an error in initialization of console occured */
    @Test
    public void testExecute() throws CommandRunException, IOException {
        final TaskPool pool = new TaskPool();
        final TaskMock task = new TaskMock();
        pool.add(task);
        final ProcessList pl = new ProcessList("list", pool);
        final PipedConsoleOutput out = new PipedConsoleOutput();
        pl.execute(out, null);

        assertTrue("Task should be contained in list",
                out.readNextLine().contains(task.getName()));

        out.close();

        try {
            pl.execute(out, null);
            fail("Printing element to closed console should raise interaction exception");
        } catch (final CommandRunException e) {
            assertEquals("Console printing error should be an interaction error",
                    CommandRunExceptionType.INTERACTION, e.getType());
        }
    }

    /** Test method for {@link net.bigeon.gclc.process.ProcessList#tip()}. */
    @Test
    public void testTip() {
        final ProcessList pl = new ProcessList("list", new TaskPool());
        assertNotNull("Command tip should be defined", pl.tip());
        assertNotNull("Command usage should be defined", pl.usageDetail());
    }
}
